#!/bin/bash
#
# ldap	This shell script takes care of starting and stopping
#	ldap servers (slapd and slurpd).
#
# chkconfig: - 39 61
# description: LDAP stands for Lightweight Directory Access Protocol, used \
#              for implementing the industry standard directory services.
# processname: slapd
# config: /etc/openldap/slapd.conf
# pidfile: /var/run/slapd.pid

SLAPDNAME=slapd-ra
SLAPD=/usr/sbin/slapd-ra
SLURPD=/usr/sbin/slurpd
LDAPCONF=/etc/openldap/slapd-ra.conf
LDAPPID=/var/run/ldap-ra.pid

# Source function library.
. /etc/init.d/functions

# Source networking configuration and check that networking is up.
if [ -r /etc/sysconfig/network ] ; then
	. /etc/sysconfig/network
	[ ${NETWORKING} = "no" ] && exit 0
fi

# Source an auxiliary options file if we have one, and pick up OPTIONS,
# SLAPD_OPTIONS, and SLURPD_OPTIONS.
if [ -r /etc/sysconfig/ldap ] ; then
	. /etc/sysconfig/ldap
fi

slapd=/usr/sbin/slapd
slurpd=/usr/sbin/slurpd
[ -x ${slapd} ] || exit 0
[ -x ${slurpd} ] || exit 0

RETVAL=0

function start() {
  echo  "Arrancando OpenLDAP 3892: "
  ARGS="-u ldap -g ldap -h ldap://:3892/"

        # Start daemons.
	prog=`basename ${slapd}`
        echo -n $"Starting $prog: "
#
#	if grep -q ^TLS /etc/openldap/slapd-ra.conf ; then
#
#	    daemon ${slapd} -u ldap -h '"ldap://:3891/ ldaps://:3891/"' -l daemon $OPTIONS $SLAPD_OPTIONS
#	    RETVAL=$?
#	else
#	    daemon ${slapd} -u ldap -h "ldap://:3891/" -l daemon $OPTIONS $SLAPD_OPTIONS
#	    RETVAL=$?
#	fi

#	daemon ${slapd} -u ldap -h "ldap://:3891/" -l daemon $OPTIONS $SLAPD_OPTIONS

  echo $SLAPD $ARGS -f $LDAPCONF -l LOCAL4
  $SLAPD $ARGS -f $LDAPCONF -l LOCAL4



	echo
#	if [ $RETVAL -eq 0 ]; then
#            if grep -q "^replogfile" /etc/openldap/slapd-ra.conf; then
#		prog=`basename ${slurpd}`
#		echo -n $"Starting $prog: "
#                daemon ${slurpd} $OPTIONS $SLURPD_OPTIONS
#		RETVAL=$?
#		echo
#            fi
#	fi
	[ $RETVAL -eq 0 ] && touch /var/lock/subsys/ldap
	return $RETVAL
}

function stop() {
        # Stop daemons.
	prog=`basename ${slapd}`
	echo -n $"Stopping $prog: "
	killproc ${slapd}
	RETVAL=$?
	echo
	if [ $RETVAL -eq 0 ]; then
	    if grep -q "^replogfile" /etc/openldap/slapd-ra.conf; then
		prog=`basename ${slurpd}`
		echo -n $"Stopping $prog: "
		killproc ${slurpd}
		RETVAL=$?
		echo
	    fi
	fi
        [ $RETVAL -eq 0 ] && rm -f /var/lock/subsys/ldap /var/run/slapd.args
	return $RETVAL
}

# See how we were called.
case "$1" in
    start)
        start
        ;;
    stop)
        stop
        ;;
    status)
        status ${slapd}
        if grep -q "^replogfile" /etc/openldap/slapd-ra.conf ; then
            status ${slurpd}
	fi
	;;
    restart)
	stop
	start
	;;
    reload)
    	killproc ${slapd} -HUP
	RETVAL=$?
	if [ $RETVAL -eq 0 ]; then
	    if grep -q "^replogfile" /etc/openldap/slapd-ra.conf; then
		killproc ${slurpd} -HUP
		RETVAL=$?
	    fi
	fi
	;;
    condrestart)
        if [ -f /var/lock/subsys/ldap ] ; then
            stop
            start
        fi
	;;
    *)
	echo $"Usage: $0 {start|stop|restart|status|condrestart}"
	RETVAL=1
esac

exit $RETVAL
